==> xmule-1.8.4.tar.bz2: xmule-1.8.4/src/PPgServer.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef PPGSERVER_H
#define PPGSERVER_H

#include "Preferences.h"
#include "resource.h"

#include <wx/panel.h>

// CPPgServer dialog

class CPPgServer : public wxPanel //CPropertyPage
{
  //DECLARE_DYNAMIC(CPPgServer)
  DECLARE_DYNAMIC_CLASS(CPPgServer)
    CPPgServer() {};

public:
	CPPgServer(wxWindow* parent);
	virtual ~CPPgServer();

	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs; }

// Dialog Data
	enum { IDD = IDD_PPG_SERVER };
protected:
	CPreferences *app_prefs;
protected:
	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	DECLARE_EVENT_TABLE()
	//DECLARE_MESSAGE_MAP()
public:
	//afx_msg void OnBnClickedCheck1();
	//virtual BOOL OnInitDialog();
 public:
	void LoadSettings(void);
public:
	void OnApply();
#if 0
	virtual BOOL OnApply();

	afx_msg void OnEnChangeServerretries()			{ SetModified(); }
	afx_msg void OnBnClickedRemovedead()			{ SetModified(); }
	afx_msg void OnBnClickedAutoserver()			{ SetModified(); }
	afx_msg void OnBnClickedUpdateserverconnect()	{ SetModified(); }
	afx_msg void OnBnClickedUpdateserverclient()	{ SetModified(); }
	afx_msg void OnBnClickedFilter()				{ SetModified(); }
	afx_msg void OnBnClickedScore()					{ SetModified(); }
#endif
	void Localize(void);
	void OnBnClickedEditadr(wxEvent& evt);
};
#endif

==> xmule-1.9.0.tar.bz2: xmule-1.9.0/src/PPgServer.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef PPGSERVER_H
#define PPGSERVER_H

#include "Preferences.h"                // Needed for CPreferences
#include <wx/panel.h>                   // Needed for wxPanel

class CPPgServer : public wxPanel
{
  //DECLARE_DYNAMIC(CPPgServer)
  DECLARE_DYNAMIC_CLASS(CPPgServer)
    CPPgServer() {};

public:
	CPPgServer(wxWindow* parent);
	virtual ~CPPgServer();

	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs; }

// Dialog Data
	enum
        {
            IDD_PPG_SERVER,
            IDD = IDD_PPG_SERVER
        };
protected:
	CPreferences *app_prefs;
protected:
	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	DECLARE_EVENT_TABLE()
	//DECLARE_MESSAGE_MAP()
public:
	//afx_msg void OnBnClickedCheck1();
	//virtual BOOL OnInitDialog();
 public:
	void LoadSettings(void);
public:
	void OnApply();
#if 0
	virtual BOOL OnApply();

	afx_msg void OnEnChangeServerretries()			{ SetModified(); }
	afx_msg void OnBnClickedRemovedead()			{ SetModified(); }
	afx_msg void OnBnClickedAutoserver()			{ SetModified(); }
	afx_msg void OnBnClickedUpdateserverconnect()	{ SetModified(); }
	afx_msg void OnBnClickedUpdateserverclient()	{ SetModified(); }
	afx_msg void OnBnClickedFilter()				{ SetModified(); }
	afx_msg void OnBnClickedScore()					{ SetModified(); }
#endif
	void Localize(void);
	void OnBnClickedEditadr(wxEvent& evt);
};
#endif
